# Credits

---
© 2025 **GeoUtils developers**.

**GeoUtils** is licensed under permissive Apache 2 license (See LICENSE file).

All contributors listed in this document are part of the **GeoUtils developers**, and their
contributions are subject to the project's copyright under the terms of the
[Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0).

This file keeps track of authors contributions.

## Development Lead

---

- **Romain Hugonnet** [@rhugonnet](https://github.com/rhugonnet) <romain.hugonnet@gmail.com>
- **Amaury Dehecq** [@adehecq](https://github/adehecq)
- **Erik Schytt Mannerfelt** [@erikmannerfelt](https://github/erikmannerfelt)
- **Andrew Tedstone** [@atedstone](https://github/atedstone)

## Contributors

---

- **Bob McNabb** [@iamdonovan](https://github/iamdonovan)
- **Eli Schwat** [@elischwat](https://github.com/elischwat)
- **Valentin Schaffner** [@vschaffn](https://github/vschaffn) <valentin.schaffner@cs-soprasteria.com>
- **Alice De Bardonnèche-Richard** [@adebardo](https://github/adebardo) <alice.de-bardonneche-richard@cs-soprasteria.com>
- **Emmanuel Dubois** [@duboise-cnes](https://github/duboise-cnes) <emmanuel.dubois@cnes.fr>
- **Amelie Froessl** [@ameliefroessl](https://github.com/ameliefroessl)
- **Friedrich Knuth** [@friedrichknuth](https://github/friedrichknuth)
- **Adrien Wehrlé** [@AdrienWehrle](https://github.com/AdrienWehrle)
- **Fabien Maussion** [@fmaussion](https://github.com/fmaussion)
- **Johannes Landmann** [@jlandmann](https://github/jlandmann)

Update here with new contributors.

## Original Developers/Designers/Supporters

---

- **Romain Hugonnet** [@rhugonnet](https://github.com/rhugonnet) <romain.hugonnet@gmail.com>
- **Amaury Dehecq** [@adehecq](https://github/adehecq)
- **Erik Schytt Mannerfelt** [@erikmannerfelt](https://github/erikmannerfelt)
- **Andrew Tedstone** [@atedstone](https://github/atedstone)
